@@ -60,12 +60,7 @@ class Logic(object):
 
     def validate(self, data, schema=None, *args, **kwargs):
 
-        try:
-            if schema is None:
-                data = self.schema.load(data, partial=kwargs.get('partial', False))
-            else:
-                data = schema().load(data, partial=kwargs.get('partial', False))
-        except ValidationError as e:
-            abort(400, e.normalized_messages())
+        if schema is None:
+            data = self.schema.load(data, partial=kwargs.get('partial', False))
         else:
-            return data
+            data = schema().load(data, partial=kwargs.get('partial', False))
